@@ -16,6 +16,7 @@
 
 from martian.error import GrokError
 from martian.util import scan_for_classes
+from martian.directive import ClassOrModuleScope
 
 AMBIGUOUS_COMPONENT = object()
 def check_module_component(factory, component, component_name, directive):
@@ -64,7 +65,30 @@ def determine_module_component(module_info, directive, iface):
     else:
         component= AMBIGUOUS_COMPONENT
 
-    module_component = directive.get(module)
+    module_component = directive.bind().get(module=module)
     if module_component is not None:
         component = module_component
     return component
+
+
+class UnambiguousComponentScope(ClassOrModuleScope):
+
+    def __init__(self, name):
+        self.name = name
+
+    def get(self, directive, component, module, default):
+        value = default
+        if component is not None:
+            value = directive.store.get(directive, component, default)
+        if value is default and module is not None:
+            value = directive.store.get(directive, module, default)
+
+        # When both 'component' and 'module' where passed in, perform
+        # a check for ambiguous components.
+        if None not in (component, module):
+            value_to_check = value
+            if value_to_check is default:
+                value_to_check = None
+            check_module_component(component, value_to_check, self.name,
+                                   directive)
+        return value
